@@ -1,6 +1,6 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,12 +25,13 @@
 #ifndef BASE_OBJECT_H
 #define BASE_OBJECT_H
 
+#include "coreglobal.h"
 #include "attributes.h"
 #include "exception.h"
 #include "schemaparser.h"
 #include "xmlparser.h"
 #include <map>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QStringList>
 #include <QTextStream>
 #include <type_traits>
@@ -80,7 +81,12 @@ enum class ObjectType: unsigned {
 	BaseTable
 };
 
-class BaseObject {
+/* Registering the ObjectType struct as a Qt MetaType in order to make
+ * it liable to be sent through signal parameters as well as to be
+ * to be used by QVariant */
+Q_DECLARE_METATYPE(ObjectType)
+
+class __libcore BaseObject {
 	private:
 		//! \brief Current PostgreSQL version used in SQL code generation
 		static QString pgsql_ver;
@@ -113,7 +119,7 @@ class BaseObject {
 		unsigned object_id;
 
 		//! \brief Objects type count declared on enum ObjectType
-		static constexpr unsigned ObjectTypeCount=enum_cast(ObjectType::BaseTable) + 1;
+		static constexpr unsigned ObjectTypeCount=enum_t(ObjectType::BaseTable) + 1;
 
 		/*! \brief Indicates whether the object is protected or not.
 		 A protected object indicates that it can not suffer changes in position
@@ -199,9 +205,9 @@ class BaseObject {
 		 It was used a numeric type to avoid the use excessive of RTTI. */
 		ObjectType obj_type;
 
-		/*! \brief This method calls the getCodeDefinition(unsigned, bool) method with the 'reduced_form' defined as 'false',
-		 This is the real implementation of the virtual method getCodeDefinition(unsigned). */
-		QString __getCodeDefinition(unsigned def_type);
+		/*! \brief This method calls the getSourceCode(SchemaParser::CodeType, bool) method with the 'reduced_form' defined as 'false',
+		 This is the real implementation of the virtual method getSourceCode(SchemaParser::CodeType). */
+		QString __getSourceCode(SchemaParser::CodeType def_type);
 
 		/*! \brief Set the database that owns the object
 		ATTENTION: calling this method with a nullptr parameter doesn't means that the object will
@@ -238,7 +244,7 @@ class BaseObject {
 		products of comparison */
 		void copyAttributes(attribs_map &attribs);
 
-		static QString getAlterDefinition(QString sch_name, attribs_map &attribs, bool ignore_ukn_attribs=false, bool ignore_empty_attribs=false);
+		static QString getAlterCode(QString sch_name, attribs_map &attribs, bool ignore_ukn_attribs=false, bool ignore_empty_attribs=false);
 
 		QString getAlterCommentDefinition(BaseObject *object, attribs_map attributes);
 
@@ -402,25 +408,25 @@ class BaseObject {
 
 		/*! \brief Forcing the class to be virtual. This means that derivated classes may
 		 override this method in order to be possible its instatiation. */
-		virtual QString getCodeDefinition(unsigned)=0;
+		virtual QString getSourceCode(SchemaParser::CodeType)=0;
 
 		/*! \brief Returns the object's SQL or XML code definition. The attribute 'reduced_form'
 		 indicates that the code generation will be an XML minimum representation
 		 of the object. See schema file for: functions, schemas, domains, types. */
-		virtual QString getCodeDefinition(unsigned def_type, bool reduced_form);
+		virtual QString getSourceCode(SchemaParser::CodeType def_type, bool reduced_form);
 
 		/*! \brief Returns the SQL definition in form of ALTER commands containing the differences between the this and 'object'.
 		This form do the camparison considering the difference on the objects' names (ignore_name_diff=false). This method
 		is used in cases when the objects' name differences are important and can't be discarded */
-		virtual QString getAlterDefinition(BaseObject *object);
+		virtual QString getAlterCode(BaseObject *object);
 
 		/*! \brief Returns the SQL definition in form of ALTER commands containing the differences between the this and 'object'.
 		The paramenter ignore_name_diff when true will cause the method to not generate a ALTER ... RENAME TO when the name of
 		objects differs. */
-		virtual QString getAlterDefinition(BaseObject *object, bool ignore_name_diff);
+		virtual QString getAlterCode(BaseObject *object, bool ignore_name_diff);
 
 		//!brief Returns the DROP statement for the object
-		virtual QString getDropDefinition(bool cascade);
+		virtual QString getDropCode(bool cascade);
 
 		//! \brief Returns if the specified type accepts to have a schema assigned
 		static bool acceptsSchema(ObjectType obj_type);
@@ -496,13 +502,13 @@ class BaseObject {
 		ObjectType::ObjBaseObject, TYPE_ATTRIBUTE and ObjectType::ObjBaseTable aren't included in return vector.
 		By default table objects (columns, trigger, constraints, etc) are included. To
 		avoid the insertion of these types set the boolean param to false. */
-		static vector<ObjectType> getObjectTypes(bool inc_table_objs=true, vector<ObjectType> exclude_types={});
+		static std::vector<ObjectType> getObjectTypes(bool inc_table_objs=true, std::vector<ObjectType> exclude_types={});
 
 		/*! \brief Returns the valid object types that are child or grouped under the specified type.
 	This method works a litte different from getObjectTypes() since this latter returns all valid types
 	and this one returns only the valid types for the current specified type. For now the only accepted
 	types are ObjectType::Database, ObjectType::Schema, ObjectType::Table, ObjectType::ForeignTable */
-		static vector<ObjectType> getChildObjectTypes(ObjectType obj_type);
+		static std::vector<ObjectType> getChildObjectTypes(ObjectType obj_type);
 
 		//! \brief Returns true when the child_type is in the list of children types of the parent_type
 		static bool isChildObjectType(ObjectType parent_type, ObjectType child_type);
