@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +27,10 @@
 
 #include "templatetype.h"
 
-class IdentityType: public TemplateType<IdentityType>{
+class __libcore IdentityType: public TemplateType<IdentityType>{
+	private:
+		static QStringList type_names;
+
 	public:
 		static constexpr unsigned Always = 1,
 		ByDefault = 2;
@@ -35,6 +38,12 @@ class IdentityType: public TemplateType<IdentityType>{
 		IdentityType(const QString &type_name);
 		IdentityType(unsigned type_id);
 		IdentityType();
+
+		static QStringList getTypes();
+
+		unsigned setType(unsigned type_id) override;
+		unsigned setType(const QString &type_name) override;
+		QString getTypeName(unsigned type_id) override;
 };
 
 #endif 
