@@ -199,6 +199,10 @@ class __libgui MainWindow: public QMainWindow, public Ui::MainWindow {
 
 		void setPluginsActions(ModelWidget *model_wgt);
 
+		/*! \brief Tries to restore the default configuration files and restart pgModeler
+		 *  in case of any configuration file is broken or missing */
+		void handleInitializationFailure(Exception &e);
+
 	public:
 		enum MWViewsId {
 			WelcomeView,
