@@ -118,6 +118,14 @@ class __libgui DatabaseImportHelper: public QObject {
 				is referenced by it in order to avoid reference breaking */
 		std::map<QString, QString> seq_tab_swap;
 
+		/*! \brief Stores the names of retrieved objects. This is used by getObjectName
+		 *  and avoid repetitive name formatting even if the object was used/accessed before */
+		std::map<unsigned, QString> cached_names,
+
+		/*! \brief Stores the signatures of retrieved objects. This is used by getObjectName
+		 *  and avoid repetitive signature formatting even if the object was used/accessed before */
+		cached_signatures;
+
 		/*! \brief Stores all columns that are inherited on the database. Since these columns are created
 		dettached from parent columns on the resulting model before the inheritances creation they
 		will be removed from their related tables if there is no object referencing them */
